@@ -1,4 +1,5 @@
 from transcriptor.speakers import Speaker
+from typing import Optional
 from dataclasses import dataclass
 
 @dataclass
@@ -6,3 +7,4 @@ class Marker:
     speaker: Speaker= None
     start_time: float=0.0
     end_time: float=0.0
+    content: Optional[str]=None
